//******************************************************************************************
//* Dodecaplex or Polydodecahedron (120 Cell), by Paul Nylander, bugman123.com, 10/21/08
//* animation: +w280 +h280 +a0.3 +am2 +r1 -p +KI0.0 +KF1.0 +KFI1 +KFF180 +KC
//******************************************************************************************

#declare camloc=3*<0,1,-sqrt(3)>;
camera{location camloc look_at <0,0,0> right x*image_width/image_height up y sky y}
light_source{camloc,1}

//Basic Functions
#macro Sqr(X) X*X #end
#macro nth(i,data) #local n=dimension_size(data,2); #local j=0; #local xlist=array[n]; #while(j<n) #local xlist[j]=data[i][j]; #local j=j+1; #end xlist #end

//44 Matrix Functions
#macro mult(A,p) <A[0].x*p.x+A[0].y*p.y+A[0].z*p.z+A[0].t*p.t,A[1].x*p.x+A[1].y*p.y+A[1].z*p.z+A[1].t*p.t,A[2].x*p.x+A[2].y*p.y+A[2].z*p.z+A[2].t*p.t,A[3].x*p.x+A[3].y*p.y+A[3].z*p.z+A[3].t*p.t> #end
#macro Mult(Q1,Q2) array[4] {
 <Q1[0].x*Q2[0].x+Q1[0].y*Q2[1].x+Q1[0].z*Q2[2].x+Q1[0].t*Q2[3].x,Q1[0].x*Q2[0].y+Q1[0].y*Q2[1].y+Q1[0].z*Q2[2].y+Q1[0].t*Q2[3].y,Q1[0].x*Q2[0].z+Q1[0].y*Q2[1].z+Q1[0].z*Q2[2].z+Q1[0].t*Q2[3].z,Q1[0].x*Q2[0].t+Q1[0].y*Q2[1].t+Q1[0].z*Q2[2].t+Q1[0].t*Q2[3].t>,
 <Q1[1].x*Q2[0].x+Q1[1].y*Q2[1].x+Q1[1].z*Q2[2].x+Q1[1].t*Q2[3].x,Q1[1].x*Q2[0].y+Q1[1].y*Q2[1].y+Q1[1].z*Q2[2].y+Q1[1].t*Q2[3].y,Q1[1].x*Q2[0].z+Q1[1].y*Q2[1].z+Q1[1].z*Q2[2].z+Q1[1].t*Q2[3].z,Q1[1].x*Q2[0].t+Q1[1].y*Q2[1].t+Q1[1].z*Q2[2].t+Q1[1].t*Q2[3].t>,
 <Q1[2].x*Q2[0].x+Q1[2].y*Q2[1].x+Q1[2].z*Q2[2].x+Q1[2].t*Q2[3].x,Q1[2].x*Q2[0].y+Q1[2].y*Q2[1].y+Q1[2].z*Q2[2].y+Q1[2].t*Q2[3].y,Q1[2].x*Q2[0].z+Q1[2].y*Q2[1].z+Q1[2].z*Q2[2].z+Q1[2].t*Q2[3].z,Q1[2].x*Q2[0].t+Q1[2].y*Q2[1].t+Q1[2].z*Q2[2].t+Q1[2].t*Q2[3].t>,
 <Q1[3].x*Q2[0].x+Q1[3].y*Q2[1].x+Q1[3].z*Q2[2].x+Q1[3].t*Q2[3].x,Q1[3].x*Q2[0].y+Q1[3].y*Q2[1].y+Q1[3].z*Q2[2].y+Q1[3].t*Q2[3].y,Q1[3].x*Q2[0].z+Q1[3].y*Q2[1].z+Q1[3].z*Q2[2].z+Q1[3].t*Q2[3].z,Q1[3].x*Q2[0].t+Q1[3].y*Q2[1].t+Q1[3].z*Q2[2].t+Q1[3].t*Q2[3].t>
} #end
#macro Rxy(theta) #local s=sin(theta); #local c=cos(theta); array[4] {<c,s,0,0>,<-s,c,0,0>,<0,0,1,0>,<0,0,0,1>} #end // 4D rotational matrices
#macro Rxz(theta) #local s=sin(theta); #local c=cos(theta); array[4] {<c,0,-s,0>,<0,1,0,0>,<s,0,c,0>,<0,0,0,1>} #end
#macro Rxw(theta) #local s=sin(theta); #local c=cos(theta); array[4] {<c,0,0,s>,<0,1,0,0>,<0,0,1,0>,<-s,0,0,c>} #end
#macro Ryz(theta) #local s=sin(theta); #local c=cos(theta); array[4] {<1,0,0,0>,<0,c,s,0>,<0,-s,c,0>,<0,0,0,1>} #end
#macro Ryw(theta) #local s=sin(theta); #local c=cos(theta); array[4] {<1,0,0,0>,<0,c,0,-s>,<0,0,1,0>,<0,s,0,c>} #end
#macro Rzw(theta) #local s=sin(theta); #local c=cos(theta); array[4] {<1,0,0,0>,<0,1,0,0>,<0,0,c,-s>,<0,0,s,c>} #end
#macro StereographicProjection(q) <q.x,q.y,q.z>/(1-q.t) #end

//Dodecaplex Data
#declare phi=(1+sqrt(5))/2; #declare a=sqrt(2)/2; #declare b=a/2; #declare c=sqrt(0.625); #declare d=0.25*phi/a; #declare e=0.25*(phi-1)/a; #declare f=0.25*Sqr(phi)/a; #declare g=0.25*Sqr(phi-1)/a;
#declare vertices=array[600] {<-g,0,-b,-f>,<g,0,-b,-f>,<-e,-e,-e,-f>,<e,-e,-e,-f>,<-e,e,-e,-f>,<e,e,-e,-f>,<0,-b,-g,-f>,<0,b,-g,-f>,<-b,-g,0,-f>,<b,-g,0,-f>,<-b,g,0,-f>,<b,g,0,-f>,<0,-b,g,-f>,<0,b,g,-f>,<-e,-e,e,-f>,<e,-e,e,-f>,<-e,e,e,-f>,<e,e,e,-f>,<-g,0,b,-f>,<g,0,b,-f>,<-e,0,-d,-c>,<e,0,-d,-c>,<-b,-b,-b,-c>,<b,-b,-b,-c>,<-b,b,-b,-c>,<b,b,-b,-c>,<0,-d,-e,-c>,<0,d,-e,-c>,<-d,-e,0,-c>,<d,-e,0,-c>,<-d,e,0,-c>,<d,e,0,-c>,<0,-d,e,-c>,<0,d,e,-c>,<-b,-b,b,-c>,<b,-b,b,-c>,<-b,b,b,-c>,<b,b,b,-c>,<-e,0,d,-c>,<e,0,d,-c>,<0,0,-a,-a>,<-b,-e,-d,-a>,<b,-e,-d,-a>,<-b,e,-d,-a>,<b,e,-d,-a>,<-e,-d,-b,-a>,<e,-d,-b,-a>,<-e,d,-b,-a>,<e,d,-b,-a>,<-d,-b,-e,-a>,<d,-b,-e,-a>,<-d,b,-e,-a>,<d,b,-e,-a>,<0,-a,0,-a>,<-a,0,0,-a>,<a,0,0,-a>,<0,a,0,-a>,<-d,-b,e,-a>,<d,-b,e,-a>,<-d,b,e,-a>,<d,b,e,-a>,<-e,-d,b,-a>,<e,-d,b,-a>,<-e,d,b,-a>,<e,d,b,-a>,<-b,-e,d,-a>,<b,-e,d,-a>,<-b,e,d,-a>,<b,e,d,-a>,<0,0,a,-a>,<0,-e,-c,-d>,<0,e,-c,-d>,<-e,-b,-a,-d>,<e,-b,-a,-d>,<-e,b,-a,-d>,<e,b,-a,-d>,<-g,-d,-d,-d>,<g,-d,-d,-d>,<-d,-g,-d,-d>,<d,-g,-d,-d>,<-d,g,-d,-d>,<d,g,-d,-d>,<-g,d,-d,-d>,<g,d,-d,-d>,<-a,-e,-b,-d>,<a,-e,-b,-d>,<-a,e,-b,-d>,<a,e,-b,-d>,<-b,-a,-e,-d>,<b,-a,-e,-d>,<-c,0,-e,-d>,<c,0,-e,-d>,<-b,a,-e,-d>,<b,a,-e,-d>,<-d,-d,-g,-d>,<d,-d,-g,-d>,<-d,d,-g,-d>,<d,d,-g,-d>,<-e,-c,0,-d>,<e,-c,0,-d>,<-e,c,0,-d>,<e,c,0,-d>,<-d,-d,g,-d>,<d,-d,g,-d>,<-d,d,g,-d>,<d,d,g,-d>,<-b,-a,e,-d>,<b,-a,e,-d>,<-c,0,e,-d>,<c,0,e,-d>,<-b,a,e,-d>,<b,a,e,-d>,<-a,-e,b,-d>,<a,-e,b,-d>,<-a,e,b,-d>,<a,e,b,-d>,<-g,-d,d,-d>,<g,-d,d,-d>,<-d,-g,d,-d>,<d,-g,d,-d>,<-d,g,d,-d>,<d,g,d,-d>,<-g,d,d,-d>,<g,d,d,-d>,<-e,-b,a,-d>,<e,-b,a,-d>,<-e,b,a,-d>,<e,b,a,-d>,<0,-e,c,-d>,<0,e,c,-d>,<0,-g,-f,-b>,<0,g,-f,-b>,<-b,-b,-c,-b>,<b,-b,-c,-b>,<-b,b,-c,-b>,<b,b,-c,-b>,<-d,-e,-a,-b>,<d,-e,-a,-b>,<-d,e,-a,-b>,<d,e,-a,-b>,<-e,-a,-d,-b>,<e,-a,-d,-b>,<-e,a,-d,-b>,<e,a,-d,-b>,<-b,-c,-b,-b>,<b,-c,-b,-b>,<-c,-b,-b,-b>,<c,-b,-b,-b>,<-c,b,-b,-b>,<c,b,-b,-b>,<-b,c,-b,-b>,<b,c,-b,-b>,<-a,-d,-e,-b>,<a,-d,-e,-b>,<-a,d,-e,-b>,<a,d,-e,-b>,<-f,0,-g,-b>,<f,0,-g,-b>,<-g,-f,0,-b>,<g,-f,0,-b>,<-g,f,0,-b>,<g,f,0,-b>,<-f,0,g,-b>,<f,0,g,-b>,<-a,-d,e,-b>,<a,-d,e,-b>,<-a,d,e,-b>,<a,d,e,-b>,<-b,-c,b,-b>,<b,-c,b,-b>,<-c,-b,b,-b>,<c,-b,b,-b>,<-c,b,b,-b>,<c,b,b,-b>,<-b,c,b,-b>,<b,c,b,-b>,<-e,-a,d,-b>,<e,-a,d,-b>,<-e,a,d,-b>,<e,a,d,-b>,<-d,-e,a,-b>,<d,-e,a,-b>,<-d,e,a,-b>,<d,e,a,-b>,<-b,-b,c,-b>,<b,-b,c,-b>,<-b,b,c,-b>,<b,b,c,-b>,<0,-g,f,-b>,<0,g,f,-b>,<-e,-e,-f,-e>,<e,-e,-f,-e>,<-e,e,-f,-e>,<e,e,-f,-e>,<-d,0,-c,-e>,<d,0,-c,-e>,<-b,-d,-a,-e>,<b,-d,-a,-e>,<-b,d,-a,-e>,<b,d,-a,-e>,<0,-c,-d,-e>,<-a,-b,-d,-e>,<a,-b,-d,-e>,<-a,b,-d,-e>,<a,b,-d,-e>,<0,c,-d,-e>,<-d,-a,-b,-e>,<d,-a,-b,-e>,<-d,a,-b,-e>,<d,a,-b,-e>,<-e,-f,-e,-e>,<e,-f,-e,-e>,<-f,-e,-e,-e>,<f,-e,-e,-e>,<-f,e,-e,-e>,<f,e,-e,-e>,<-e,f,-e,-e>,<e,f,-e,-e>,<-c,-d,0,-e>,<c,-d,0,-e>,<-c,d,0,-e>,<c,d,0,-e>,<-e,-f,e,-e>,<e,-f,e,-e>,<-f,-e,e,-e>,<f,-e,e,-e>,<-f,e,e,-e>,<f,e,e,-e>,<-e,f,e,-e>,<e,f,e,-e>,<-d,-a,b,-e>,<d,-a,b,-e>,<-d,a,b,-e>,<d,a,b,-e>,<0,-c,d,-e>,<-a,-b,d,-e>,<a,-b,d,-e>,<-a,b,d,-e>,<a,b,d,-e>,<0,c,d,-e>,<-b,-d,a,-e>,<b,-d,a,-e>,<-b,d,a,-e>,<b,d,a,-e>,<-d,0,c,-e>,<d,0,c,-e>,<-e,-e,f,-e>,<e,-e,f,-e>,<-e,e,f,-e>,<e,e,f,-e>,<-b,0,-f,-g>,<b,0,-f,-g>,<-d,-d,-d,-g>,<d,-d,-d,-g>,<-d,d,-d,-g>,<d,d,-d,-g>,<0,-f,-b,-g>,<0,f,-b,-g>,<-f,-b,0,-g>,<f,-b,0,-g>,<-f,b,0,-g>,<f,b,0,-g>,<0,-f,b,-g>,<0,f,b,-g>,<-d,-d,d,-g>,<d,-d,d,-g>,<-d,d,d,-g>,<d,d,d,-g>,<-b,0,f,-g>,<b,0,f,-g>,<-g,-b,-f,0>,<g,-b,-f,0>,<-g,b,-f,0>,<g,b,-f,0>,<-e,-d,-c,0>,<e,-d,-c,0>,<-e,d,-c,0>,<e,d,-c,0>,<0,-a,-a,0>,<-a,0,-a,0>,<a,0,-a,0>,<0,a,-a,0>,<-c,-e,-d,0>,<c,-e,-d,0>,<-c,e,-d,0>,<c,e,-d,0>,<-f,-g,-b,0>,<f,-g,-b,0>,<-f,g,-b,0>,<f,g,-b,0>,<-d,-c,-e,0>,<d,-c,-e,0>,<-d,c,-e,0>,<d,c,-e,0>,<-b,-f,-g,0>,<b,-f,-g,0>,<-b,f,-g,0>,<b,f,-g,0>,<-a,-a,0,0>,<a,-a,0,0>,<-a,a,0,0>,<a,a,0,0>,<-b,-f,g,0>,<b,-f,g,0>,<-b,f,g,0>,<b,f,g,0>,<-d,-c,e,0>,<d,-c,e,0>,<-d,c,e,0>,<d,c,e,0>,<-f,-g,b,0>,<f,-g,b,0>,<-f,g,b,0>,<f,g,b,0>,<-c,-e,d,0>,<c,-e,d,0>,<-c,e,d,0>,<c,e,d,0>,<0,-a,a,0>,<-a,0,a,0>,<a,0,a,0>,<0,a,a,0>,<-e,-d,c,0>,<e,-d,c,0>,<-e,d,c,0>,<e,d,c,0>,<-g,-b,f,0>,<g,-b,f,0>,<-g,b,f,0>,<g,b,f,0>,<-b,0,-f,g>,<b,0,-f,g>,<-d,-d,-d,g>,<d,-d,-d,g>,<-d,d,-d,g>,<d,d,-d,g>,<0,-f,-b,g>,<0,f,-b,g>,<-f,-b,0,g>,<f,-b,0,g>,<-f,b,0,g>,<f,b,0,g>,<0,-f,b,g>,<0,f,b,g>,<-d,-d,d,g>,<d,-d,d,g>,<-d,d,d,g>,<d,d,d,g>,<-b,0,f,g>,<b,0,f,g>,<-e,-e,-f,e>,<e,-e,-f,e>,<-e,e,-f,e>,<e,e,-f,e>,<-d,0,-c,e>,<d,0,-c,e>,<-b,-d,-a,e>,<b,-d,-a,e>,<-b,d,-a,e>,<b,d,-a,e>,<0,-c,-d,e>,<-a,-b,-d,e>,<a,-b,-d,e>,<-a,b,-d,e>,<a,b,-d,e>,<0,c,-d,e>,<-d,-a,-b,e>,<d,-a,-b,e>,<-d,a,-b,e>,<d,a,-b,e>,<-e,-f,-e,e>,<e,-f,-e,e>,<-f,-e,-e,e>,<f,-e,-e,e>,<-f,e,-e,e>,<f,e,-e,e>,<-e,f,-e,e>,<e,f,-e,e>,<-c,-d,0,e>,<c,-d,0,e>,<-c,d,0,e>,<c,d,0,e>,<-e,-f,e,e>,<e,-f,e,e>,<-f,-e,e,e>,<f,-e,e,e>,<-f,e,e,e>,<f,e,e,e>,<-e,f,e,e>,<e,f,e,e>,<-d,-a,b,e>,<d,-a,b,e>,<-d,a,b,e>,<d,a,b,e>,<0,-c,d,e>,<-a,-b,d,e>,<a,-b,d,e>,<-a,b,d,e>,<a,b,d,e>,<0,c,d,e>,<-b,-d,a,e>,<b,-d,a,e>,<-b,d,a,e>,<b,d,a,e>,<-d,0,c,e>,<d,0,c,e>,<-e,-e,f,e>,<e,-e,f,e>,<-e,e,f,e>,<e,e,f,e>,<0,-g,-f,b>,<0,g,-f,b>,<-b,-b,-c,b>,<b,-b,-c,b>,<-b,b,-c,b>,<b,b,-c,b>,<-d,-e,-a,b>,<d,-e,-a,b>,<-d,e,-a,b>,<d,e,-a,b>,<-e,-a,-d,b>,<e,-a,-d,b>,<-e,a,-d,b>,<e,a,-d,b>,<-b,-c,-b,b>,<b,-c,-b,b>,<-c,-b,-b,b>,<c,-b,-b,b>,<-c,b,-b,b>,<c,b,-b,b>,<-b,c,-b,b>,<b,c,-b,b>,<-a,-d,-e,b>,<a,-d,-e,b>,<-a,d,-e,b>,<a,d,-e,b>,<-f,0,-g,b>,<f,0,-g,b>,<-g,-f,0,b>,<g,-f,0,b>,<-g,f,0,b>,<g,f,0,b>,<-f,0,g,b>,<f,0,g,b>,<-a,-d,e,b>,<a,-d,e,b>,<-a,d,e,b>,<a,d,e,b>,<-b,-c,b,b>,<b,-c,b,b>,<-c,-b,b,b>,<c,-b,b,b>,<-c,b,b,b>,<c,b,b,b>,<-b,c,b,b>,<b,c,b,b>,<-e,-a,d,b>,<e,-a,d,b>,<-e,a,d,b>,<e,a,d,b>,<-d,-e,a,b>,<d,-e,a,b>,<-d,e,a,b>,<d,e,a,b>,<-b,-b,c,b>,<b,-b,c,b>,<-b,b,c,b>,<b,b,c,b>,<0,-g,f,b>,<0,g,f,b>,<0,-e,-c,d>,<0,e,-c,d>,<-e,-b,-a,d>,<e,-b,-a,d>,<-e,b,-a,d>,<e,b,-a,d>,<-g,-d,-d,d>,<g,-d,-d,d>,<-d,-g,-d,d>,<d,-g,-d,d>,<-d,g,-d,d>,<d,g,-d,d>,<-g,d,-d,d>,<g,d,-d,d>,<-a,-e,-b,d>,<a,-e,-b,d>,<-a,e,-b,d>,<a,e,-b,d>,<-b,-a,-e,d>,<b,-a,-e,d>,<-c,0,-e,d>,<c,0,-e,d>,<-b,a,-e,d>,<b,a,-e,d>,<-d,-d,-g,d>,<d,-d,-g,d>,<-d,d,-g,d>,<d,d,-g,d>,<-e,-c,0,d>,<e,-c,0,d>,<-e,c,0,d>,<e,c,0,d>,<-d,-d,g,d>,<d,-d,g,d>,<-d,d,g,d>,<d,d,g,d>,<-b,-a,e,d>,<b,-a,e,d>,<-c,0,e,d>,<c,0,e,d>,<-b,a,e,d>,<b,a,e,d>,<-a,-e,b,d>,<a,-e,b,d>,<-a,e,b,d>,<a,e,b,d>,<-g,-d,d,d>,<g,-d,d,d>,<-d,-g,d,d>,<d,-g,d,d>,<-d,g,d,d>,<d,g,d,d>,<-g,d,d,d>,<g,d,d,d>,<-e,-b,a,d>,<e,-b,a,d>,<-e,b,a,d>,<e,b,a,d>,<0,-e,c,d>,<0,e,c,d>,<0,0,-a,a>,<-b,-e,-d,a>,<b,-e,-d,a>,<-b,e,-d,a>,<b,e,-d,a>,<-e,-d,-b,a>,<e,-d,-b,a>,<-e,d,-b,a>,<e,d,-b,a>,<-d,-b,-e,a>,<d,-b,-e,a>,<-d,b,-e,a>,<d,b,-e,a>,<0,-a,0,a>,<-a,0,0,a>,<a,0,0,a>,<0,a,0,a>,<-d,-b,e,a>,<d,-b,e,a>,<-d,b,e,a>,<d,b,e,a>,<-e,-d,b,a>,<e,-d,b,a>,<-e,d,b,a>,<e,d,b,a>,<-b,-e,d,a>,<b,-e,d,a>,<-b,e,d,a>,<b,e,d,a>,<0,0,a,a>,<-e,0,-d,c>,<e,0,-d,c>,<-b,-b,-b,c>,<b,-b,-b,c>,<-b,b,-b,c>,<b,b,-b,c>,<0,-d,-e,c>,<0,d,-e,c>,<-d,-e,0,c>,<d,-e,0,c>,<-d,e,0,c>,<d,e,0,c>,<0,-d,e,c>,<0,d,e,c>,<-b,-b,b,c>,<b,-b,b,c>,<-b,b,b,c>,<b,b,b,c>,<-e,0,d,c>,<e,0,d,c>,<-g,0,-b,f>,<g,0,-b,f>,<-e,-e,-e,f>,<e,-e,-e,f>,<-e,e,-e,f>,<e,e,-e,f>,<0,-b,-g,f>,<0,b,-g,f>,<-b,-g,0,f>,<b,-g,0,f>,<-b,g,0,f>,<b,g,0,f>,<0,-b,g,f>,<0,b,g,f>,<-e,-e,e,f>,<e,-e,e,f>,<-e,e,e,f>,<e,e,e,f>,<-g,0,b,f>,<g,0,b,f>};
#declare Q=Mult(Rzw(2*pi*clock),Mult(Ryw(pi/2),Rxz(pi/2))); // apply 4D rotation
#declare i=0; #while(i<600) #declare vertices[i]=mult(Q,vertices[i]); #declare i=i+1; #end
#declare faces=array[720] {<0,1,3,6,2>,<0,1,5,7,4>,<0,1,21,40,20>,<0,2,8,10,4>,<0,2,22,41,20>,<0,4,24,43,20>,<1,3,9,11,5>,<1,3,23,42,21>,<1,5,25,44,21>,<2,6,12,14,8>,<2,6,26,45,22>,<2,8,28,49,22>,<3,6,12,15,9>,<3,6,26,46,23>,<3,9,29,50,23>,<4,7,13,16,10>,<4,7,27,47,24>,<4,10,30,51,24>,<5,7,13,17,11>,<5,7,27,48,25>,<5,11,31,52,25>,<6,12,32,53,26>,<7,13,33,56,27>,<8,10,16,18,14>,<8,10,30,54,28>,<8,14,34,57,28>,<9,11,17,19,15>,<9,11,31,55,29>,<9,15,35,58,29>,<10,16,36,59,30>,<11,17,37,60,31>,<12,14,18,19,15>,<12,14,34,61,32>,<12,15,35,62,32>,<13,16,18,19,17>,<13,16,36,63,33>,<13,17,37,64,33>,<14,18,38,65,34>,<15,19,39,66,35>,<16,18,38,67,36>,<17,19,39,68,37>,<18,19,39,69,38>,<20,40,70,72,41>,<20,40,71,74,43>,<20,41,78,80,43>,<21,40,70,73,42>,<21,40,71,75,44>,<21,42,79,81,44>,<22,41,72,76,45>,<22,41,78,84,49>,<22,45,88,94,49>,<23,42,73,77,46>,<23,42,79,85,50>,<23,46,89,95,50>,<24,43,74,82,47>,<24,43,80,86,51>,<24,47,92,96,51>,<25,44,75,83,48>,<25,44,81,87,52>,<25,48,93,97,52>,<26,45,76,77,46>,<26,45,88,98,53>,<26,46,89,99,53>,<27,47,82,83,48>,<27,47,92,100,56>,<27,48,93,101,56>,<28,49,84,90,54>,<28,49,94,102,57>,<28,54,108,112,57>,<29,50,85,91,55>,<29,50,95,103,58>,<29,55,109,113,58>,<30,51,86,90,54>,<30,51,96,104,59>,<30,54,108,114,59>,<31,52,87,91,55>,<31,52,97,105,60>,<31,55,109,115,60>,<32,53,98,106,61>,<32,53,99,107,62>,<32,61,116,117,62>,<33,56,100,110,63>,<33,56,101,111,64>,<33,63,122,123,64>,<34,57,102,106,61>,<34,57,112,118,65>,<34,61,116,124,65>,<35,58,103,107,62>,<35,58,113,119,66>,<35,62,117,125,66>,<36,59,104,110,63>,<36,59,114,120,67>,<36,63,122,126,67>,<37,60,105,111,64>,<37,60,115,121,68>,<37,64,123,127,68>,<38,65,118,120,67>,<38,65,124,128,69>,<38,67,126,129,69>,<39,66,119,121,68>,<39,66,125,128,69>,<39,68,127,129,69>,<40,70,130,131,71>,<41,72,132,136,78>,<42,73,133,137,79>,<43,74,134,138,80>,<44,75,135,139,81>,<45,76,140,144,88>,<46,77,141,145,89>,<47,82,142,150,92>,<48,83,143,151,93>,<49,84,146,152,94>,<50,85,147,153,95>,<51,86,148,154,96>,<52,87,149,155,97>,<53,98,158,159,99>,<54,90,156,162,108>,<55,91,157,163,109>,<56,100,160,161,101>,<57,102,164,170,112>,<58,103,165,171,113>,<59,104,166,172,114>,<60,105,167,173,115>,<61,106,168,176,116>,<62,107,169,177,117>,<63,110,174,178,122>,<64,111,175,179,123>,<65,118,180,184,124>,<66,119,181,185,125>,<67,120,182,186,126>,<68,121,183,187,127>,<69,128,188,189,129>,<70,72,76,77,73>,<70,72,132,190,130>,<70,73,133,191,130>,<71,74,82,83,75>,<71,74,134,192,131>,<71,75,135,193,131>,<72,76,140,196,132>,<73,77,141,197,133>,<74,82,142,198,134>,<75,83,143,199,135>,<76,77,141,200,140>,<78,80,86,90,84>,<78,80,138,194,136>,<78,84,146,201,136>,<79,81,87,91,85>,<79,81,139,195,137>,<79,85,147,202,137>,<80,86,148,203,138>,<81,87,149,204,139>,<82,83,143,205,142>,<84,90,156,212,146>,<85,91,157,213,147>,<86,90,156,214,148>,<87,91,157,215,149>,<88,94,102,106,98>,<88,94,152,206,144>,<88,98,158,210,144>,<89,95,103,107,99>,<89,95,153,207,145>,<89,99,159,211,145>,<92,96,104,110,100>,<92,96,154,208,150>,<92,100,160,216,150>,<93,97,105,111,101>,<93,97,155,209,151>,<93,101,161,217,151>,<94,102,164,218,152>,<95,103,165,219,153>,<96,104,166,220,154>,<97,105,167,221,155>,<98,106,168,222,158>,<99,107,169,223,159>,<100,110,174,228,160>,<101,111,175,229,161>,<102,106,168,230,164>,<103,107,169,231,165>,<104,110,174,232,166>,<105,111,175,233,167>,<108,112,118,120,114>,<108,112,170,224,162>,<108,114,172,226,162>,<109,113,119,121,115>,<109,113,171,225,163>,<109,115,173,227,163>,<112,118,180,235,170>,<113,119,181,236,171>,<114,120,182,237,172>,<115,121,183,238,173>,<116,117,125,128,124>,<116,117,177,234,176>,<116,124,184,240,176>,<117,125,185,241,177>,<118,120,182,244,180>,<119,121,183,245,181>,<122,123,127,129,126>,<122,123,179,239,178>,<122,126,186,242,178>,<123,127,187,243,179>,<124,128,188,246,184>,<125,128,188,247,185>,<126,129,189,248,186>,<127,129,189,249,187>,<130,131,192,250,190>,<130,131,193,251,191>,<130,190,270,271,191>,<131,192,272,273,193>,<132,136,194,250,190>,<132,136,201,252,196>,<132,190,270,274,196>,<133,137,195,251,191>,<133,137,202,253,197>,<133,191,271,275,197>,<134,138,194,250,192>,<134,138,203,254,198>,<134,192,272,276,198>,<135,139,195,251,193>,<135,139,204,255,199>,<135,193,273,277,199>,<136,194,279,282,201>,<137,195,280,283,202>,<138,194,279,284,203>,<139,195,280,285,204>,<140,144,206,252,196>,<140,144,210,256,200>,<140,196,274,278,200>,<141,145,207,253,197>,<141,145,211,256,200>,<141,197,275,278,200>,<142,150,208,254,198>,<142,150,216,257,205>,<142,198,276,281,205>,<143,151,209,255,199>,<143,151,217,257,205>,<143,199,277,281,205>,<144,206,290,294,210>,<145,207,291,295,211>,<146,152,206,252,201>,<146,152,218,258,212>,<146,201,282,286,212>,<147,153,207,253,202>,<147,153,219,259,213>,<147,202,283,287,213>,<148,154,208,254,203>,<148,154,220,260,214>,<148,203,284,288,214>,<149,155,209,255,204>,<149,155,221,261,215>,<149,204,285,289,215>,<150,208,292,296,216>,<151,209,293,297,217>,<152,206,290,298,218>,<153,207,291,299,219>,<154,208,292,300,220>,<155,209,293,301,221>,<156,162,224,258,212>,<156,162,226,260,214>,<156,212,286,288,214>,<157,163,225,259,213>,<157,163,227,261,215>,<157,213,287,289,215>,<158,159,211,256,210>,<158,159,223,262,222>,<158,210,294,302,222>,<159,211,295,303,223>,<160,161,217,257,216>,<160,161,229,263,228>,<160,216,296,304,228>,<161,217,297,305,229>,<162,224,310,312,226>,<163,225,311,313,227>,<164,170,224,258,218>,<164,170,235,264,230>,<164,218,298,306,230>,<165,171,225,259,219>,<165,171,236,265,231>,<165,219,299,307,231>,<166,172,226,260,220>,<166,172,237,266,232>,<166,220,300,308,232>,<167,173,227,261,221>,<167,173,238,267,233>,<167,221,301,309,233>,<168,176,234,262,222>,<168,176,240,264,230>,<168,222,302,306,230>,<169,177,234,262,223>,<169,177,241,265,231>,<169,223,303,307,231>,<170,224,310,314,235>,<171,225,311,315,236>,<172,226,312,316,237>,<173,227,313,317,238>,<174,178,239,263,228>,<174,178,242,266,232>,<174,228,304,308,232>,<175,179,239,263,229>,<175,179,243,267,233>,<175,229,305,309,233>,<176,234,318,322,240>,<177,234,318,323,241>,<178,239,321,324,242>,<179,239,321,325,243>,<180,184,240,264,235>,<180,184,246,268,244>,<180,235,314,319,244>,<181,185,241,265,236>,<181,185,247,269,245>,<181,236,315,320,245>,<182,186,242,266,237>,<182,186,248,268,244>,<182,237,316,319,244>,<183,187,243,267,238>,<183,187,249,269,245>,<183,238,317,320,245>,<184,240,322,326,246>,<185,241,323,327,247>,<186,242,324,328,248>,<187,243,325,329,249>,<188,189,248,268,246>,<188,189,249,269,247>,<188,246,326,327,247>,<189,248,328,329,249>,<190,250,330,350,270>,<191,251,331,351,271>,<192,250,330,352,272>,<193,251,331,353,273>,<194,250,330,354,279>,<195,251,331,355,280>,<196,252,332,356,274>,<197,253,333,357,275>,<198,254,334,358,276>,<199,255,335,359,277>,<200,256,336,360,278>,<201,252,332,361,282>,<202,253,333,362,283>,<203,254,334,363,284>,<204,255,335,364,285>,<205,257,337,365,281>,<206,252,332,366,290>,<207,253,333,367,291>,<208,254,334,368,292>,<209,255,335,369,293>,<210,256,336,370,294>,<211,256,336,371,295>,<212,258,338,372,286>,<213,259,339,373,287>,<214,260,340,374,288>,<215,261,341,375,289>,<216,257,337,376,296>,<217,257,337,377,297>,<218,258,338,378,298>,<219,259,339,379,299>,<220,260,340,380,300>,<221,261,341,381,301>,<222,262,342,382,302>,<223,262,342,383,303>,<224,258,338,384,310>,<225,259,339,385,311>,<226,260,340,386,312>,<227,261,341,387,313>,<228,263,343,388,304>,<229,263,343,389,305>,<230,264,344,390,306>,<231,265,345,391,307>,<232,266,346,392,308>,<233,267,347,393,309>,<234,262,342,394,318>,<235,264,344,395,314>,<236,265,345,396,315>,<237,266,346,397,316>,<238,267,347,398,317>,<239,263,343,399,321>,<240,264,344,400,322>,<241,265,345,401,323>,<242,266,346,402,324>,<243,267,347,403,325>,<244,268,348,404,319>,<245,269,349,405,320>,<246,268,348,406,326>,<247,269,349,407,327>,<248,268,348,408,328>,<249,269,349,409,329>,<270,271,275,278,274>,<270,271,351,410,350>,<270,274,356,412,350>,<271,275,357,413,351>,<272,273,277,281,276>,<272,273,353,411,352>,<272,276,358,414,352>,<273,277,359,415,353>,<274,278,360,420,356>,<275,278,360,421,357>,<276,281,365,422,358>,<277,281,365,423,359>,<279,282,286,288,284>,<279,282,361,416,354>,<279,284,363,418,354>,<280,283,287,289,285>,<280,283,362,417,355>,<280,285,364,419,355>,<282,286,372,426,361>,<283,287,373,427,362>,<284,288,374,428,363>,<285,289,375,429,364>,<286,288,374,436,372>,<287,289,375,437,373>,<290,294,302,306,298>,<290,294,370,424,366>,<290,298,378,432,366>,<291,295,303,307,299>,<291,295,371,425,367>,<291,299,379,433,367>,<292,296,304,308,300>,<292,296,376,430,368>,<292,300,380,434,368>,<293,297,305,309,301>,<293,297,377,431,369>,<293,301,381,435,369>,<294,302,382,438,370>,<295,303,383,439,371>,<296,304,388,440,376>,<297,305,389,441,377>,<298,306,390,444,378>,<299,307,391,445,379>,<300,308,392,446,380>,<301,309,393,447,381>,<302,306,390,448,382>,<303,307,391,449,383>,<304,308,392,454,388>,<305,309,393,455,389>,<310,312,316,319,314>,<310,312,386,442,384>,<310,314,395,450,384>,<311,313,317,320,315>,<311,313,387,443,385>,<311,315,396,451,385>,<312,316,397,452,386>,<313,317,398,453,387>,<314,319,404,460,395>,<315,320,405,461,396>,<316,319,404,462,397>,<317,320,405,463,398>,<318,322,326,327,323>,<318,322,400,456,394>,<318,323,401,457,394>,<321,324,328,329,325>,<321,324,402,458,399>,<321,325,403,459,399>,<322,326,406,464,400>,<323,327,407,465,401>,<324,328,408,466,402>,<325,329,409,467,403>,<326,327,407,468,406>,<328,329,409,469,408>,<330,350,410,411,352>,<330,350,412,416,354>,<330,352,414,418,354>,<331,351,410,411,353>,<331,351,413,417,355>,<331,353,415,419,355>,<332,356,412,416,361>,<332,356,420,424,366>,<332,361,426,432,366>,<333,357,413,417,362>,<333,357,421,425,367>,<333,362,427,433,367>,<334,358,414,418,363>,<334,358,422,430,368>,<334,363,428,434,368>,<335,359,415,419,364>,<335,359,423,431,369>,<335,364,429,435,369>,<336,360,420,424,370>,<336,360,421,425,371>,<336,370,438,439,371>,<337,365,422,430,376>,<337,365,423,431,377>,<337,376,440,441,377>,<338,372,426,432,378>,<338,372,436,442,384>,<338,378,444,450,384>,<339,373,427,433,379>,<339,373,437,443,385>,<339,379,445,451,385>,<340,374,428,434,380>,<340,374,436,442,386>,<340,380,446,452,386>,<341,375,429,435,381>,<341,375,437,443,387>,<341,381,447,453,387>,<342,382,438,439,383>,<342,382,448,456,394>,<342,383,449,457,394>,<343,388,440,441,389>,<343,388,454,458,399>,<343,389,455,459,399>,<344,390,444,450,395>,<344,390,448,456,400>,<344,395,460,464,400>,<345,391,445,451,396>,<345,391,449,457,401>,<345,396,461,465,401>,<346,392,446,452,397>,<346,392,454,458,402>,<346,397,462,466,402>,<347,393,447,453,398>,<347,393,455,459,403>,<347,398,463,467,403>,<348,404,460,464,406>,<348,404,462,466,408>,<348,406,468,469,408>,<349,405,461,465,407>,<349,405,463,467,409>,<349,407,468,469,409>,<350,410,470,472,412>,<351,410,470,473,413>,<352,411,471,474,414>,<353,411,471,475,415>,<354,416,478,480,418>,<355,417,479,481,419>,<356,412,472,476,420>,<357,413,473,477,421>,<358,414,474,482,422>,<359,415,475,483,423>,<360,420,476,477,421>,<361,416,478,484,426>,<362,417,479,485,427>,<363,418,480,486,428>,<364,419,481,487,429>,<365,422,482,483,423>,<366,424,488,494,432>,<367,425,489,495,433>,<368,430,492,496,434>,<369,431,493,497,435>,<370,424,488,498,438>,<371,425,489,499,439>,<372,426,484,490,436>,<373,427,485,491,437>,<374,428,486,490,436>,<375,429,487,491,437>,<376,430,492,500,440>,<377,431,493,501,441>,<378,432,494,502,444>,<379,433,495,503,445>,<380,434,496,504,446>,<381,435,497,505,447>,<382,438,498,506,448>,<383,439,499,507,449>,<384,442,508,512,450>,<385,443,509,513,451>,<386,442,508,514,452>,<387,443,509,515,453>,<388,440,500,510,454>,<389,441,501,511,455>,<390,444,502,506,448>,<391,445,503,507,449>,<392,446,504,510,454>,<393,447,505,511,455>,<394,456,516,517,457>,<395,450,512,518,460>,<396,451,513,519,461>,<397,452,514,520,462>,<398,453,515,521,463>,<399,458,522,523,459>,<400,456,516,524,464>,<401,457,517,525,465>,<402,458,522,526,466>,<403,459,523,527,467>,<404,460,518,520,462>,<405,461,519,521,463>,<406,464,524,528,468>,<407,465,525,528,468>,<408,466,526,529,469>,<409,467,527,529,469>,<410,411,471,530,470>,<412,416,478,531,472>,<413,417,479,532,473>,<414,418,480,533,474>,<415,419,481,534,475>,<420,424,488,535,476>,<421,425,489,536,477>,<422,430,492,537,482>,<423,431,493,538,483>,<426,432,494,539,484>,<427,433,495,540,485>,<428,434,496,541,486>,<429,435,497,542,487>,<436,442,508,544,490>,<437,443,509,545,491>,<438,439,499,543,498>,<440,441,501,546,500>,<444,450,512,547,502>,<445,451,513,548,503>,<446,452,514,549,504>,<447,453,515,550,505>,<448,456,516,551,506>,<449,457,517,552,507>,<454,458,522,553,510>,<455,459,523,554,511>,<460,464,524,555,518>,<461,465,525,556,519>,<462,466,526,557,520>,<463,467,527,558,521>,<468,469,529,559,528>,<470,472,476,477,473>,<470,472,531,560,530>,<470,473,532,561,530>,<471,474,482,483,475>,<471,474,533,560,530>,<471,475,534,561,530>,<472,476,535,562,531>,<473,477,536,563,532>,<474,482,537,564,533>,<475,483,538,565,534>,<476,477,536,566,535>,<478,480,486,490,484>,<478,480,533,560,531>,<478,484,539,562,531>,<479,481,487,491,485>,<479,481,534,561,532>,<479,485,540,563,532>,<480,486,541,564,533>,<481,487,542,565,534>,<482,483,538,567,537>,<484,490,544,568,539>,<485,491,545,569,540>,<486,490,544,570,541>,<487,491,545,571,542>,<488,494,502,506,498>,<488,494,539,562,535>,<488,498,543,566,535>,<489,495,503,507,499>,<489,495,540,563,536>,<489,499,543,566,536>,<492,496,504,510,500>,<492,496,541,564,537>,<492,500,546,567,537>,<493,497,505,511,501>,<493,497,542,565,538>,<493,501,546,567,538>,<494,502,547,568,539>,<495,503,548,569,540>,<496,504,549,570,541>,<497,505,550,571,542>,<498,506,551,572,543>,<499,507,552,572,543>,<500,510,553,573,546>,<501,511,554,573,546>,<502,506,551,574,547>,<503,507,552,575,548>,<504,510,553,576,549>,<505,511,554,577,550>,<508,512,518,520,514>,<508,512,547,568,544>,<508,514,549,570,544>,<509,513,519,521,515>,<509,513,548,569,545>,<509,515,550,571,545>,<512,518,555,574,547>,<513,519,556,575,548>,<514,520,557,576,549>,<515,521,558,577,550>,<516,517,525,528,524>,<516,517,552,572,551>,<516,524,555,574,551>,<517,525,556,575,552>,<518,520,557,578,555>,<519,521,558,579,556>,<522,523,527,529,526>,<522,523,554,573,553>,<522,526,557,576,553>,<523,527,558,577,554>,<524,528,559,578,555>,<525,528,559,579,556>,<526,529,559,578,557>,<527,529,559,579,558>,<530,560,580,581,561>,<531,560,580,582,562>,<532,561,581,583,563>,<533,560,580,584,564>,<534,561,581,585,565>,<535,562,582,586,566>,<536,563,583,586,566>,<537,564,584,587,567>,<538,565,585,587,567>,<539,562,582,588,568>,<540,563,583,589,569>,<541,564,584,590,570>,<542,565,585,591,571>,<543,566,586,592,572>,<544,568,588,590,570>,<545,569,589,591,571>,<546,567,587,593,573>,<547,568,588,594,574>,<548,569,589,595,575>,<549,570,590,596,576>,<550,571,591,597,577>,<551,572,592,594,574>,<552,572,592,595,575>,<553,573,593,596,576>,<554,573,593,597,577>,<555,574,594,598,578>,<556,575,595,599,579>,<557,576,596,598,578>,<558,577,597,599,579>,<559,578,598,599,579>,<580,581,583,586,582>,<580,581,585,587,584>,<580,582,588,590,584>,<581,583,589,591,585>,<582,586,592,594,588>,<583,586,592,595,589>,<584,587,593,596,590>,<585,587,593,597,591>,<588,590,596,598,594>,<589,591,597,599,595>,<592,594,598,599,595>,<593,596,598,599,597>};
#declare Cells=array[120][12] {{256,257,258,270,346,348,358,360,406,433,481,487},{238,239,240,252,335,340,346,352,402,410,464,480},{272,273,274,290,352,358,364,369,424,434,482,498},{66,67,68,111,116,119,152,168,181,239,256,272},{480,481,482,538,544,550,585,589,593,626,642,655},{143,144,145,149,152,154,220,222,240,246,258,396},{396,397,398,402,404,406,520,527,529,538,540,617},{180,181,182,186,188,194,270,290,292,306,312,432},{432,433,434,438,440,442,550,552,561,563,570,654},{72,73,74,113,116,121,154,170,182,245,257,278},{486,487,488,540,546,552,587,589,595,628,644,656},{244,245,246,254,337,342,348,354,404,416,470,486},{278,279,280,292,354,360,366,371,426,438,488,504},{156,157,158,168,172,176,236,252,264,274,286,408},{408,409,410,420,424,428,532,536,544,548,556,630},{48,49,50,103,107,111,138,145,157,209,224,238},{462,463,464,522,527,532,577,581,585,612,619,631},{84,85,86,119,123,127,176,186,192,273,285,304},{498,499,500,556,561,566,593,597,601,650,660,666},{208,209,210,220,324,328,330,335,386,397,457,462},{304,305,306,316,369,374,378,380,440,450,500,510},{3,4,5,11,17,24,44,49,55,66,72,143},{617,618,619,623,626,628,679,681,687,689,692,710},{23,24,25,29,37,39,68,74,85,91,96,180},{654,655,656,660,662,668,692,695,697,703,705,716},{214,215,216,222,326,328,332,337,390,398,458,468},{310,311,312,318,371,376,378,382,442,452,506,511},{54,55,56,105,109,113,140,149,163,215,230,244},{468,469,470,524,529,534,579,583,587,614,623,637},{90,91,92,121,125,129,178,188,198,279,295,310},{504,505,506,558,563,568,595,599,603,652,662,672},{162,163,164,170,174,178,250,254,268,280,296,414},{414,415,416,422,426,430,534,542,546,554,558,636},{224,225,226,236,330,334,340,344,392,409,463,474},{284,285,286,300,356,364,368,374,428,445,493,499},{9,10,11,21,25,32,50,61,67,78,84,156},{630,631,632,642,646,650,683,687,691,695,699,712},{42,43,44,102,103,105,133,136,144,204,208,214},{456,457,458,516,518,520,576,577,579,607,610,618},{96,97,98,127,129,131,194,200,202,305,311,320},{510,511,512,570,572,574,601,603,605,668,674,676},{15,16,17,22,29,35,56,64,73,81,90,162},{636,637,638,644,648,652,685,689,694,697,701,714},{230,231,232,250,332,339,342,350,394,415,469,477},{294,295,296,302,362,366,373,376,430,448,496,505},{262,263,264,265,344,345,356,357,420,421,476,492},{60,61,62,107,108,115,142,158,161,225,228,262},{474,475,476,526,536,537,581,582,591,616,632,635},{78,79,80,115,123,124,172,173,191,263,284,287},{492,493,494,548,549,560,591,597,598,646,647,665},{132,133,134,138,139,142,206,210,213,226,229,384},{384,385,386,387,392,393,516,517,522,523,526,606},{190,191,192,193,200,201,300,301,316,317,322,444},{444,445,446,450,451,454,560,566,567,572,573,664},{0,2,4,7,10,13,42,45,48,51,60,132},{606,607,608,612,613,616,678,679,680,683,684,708},{31,32,33,37,38,41,80,86,89,97,100,190},{664,665,666,667,674,675,699,700,703,704,707,718},{204,205,206,207,324,325,326,327,385,389,456,459},{0,1,3,6,9,12,15,18,23,26,31,34},{708,709,710,711,712,713,714,715,716,717,718,719},{320,321,322,323,380,381,382,383,454,455,512,515},{1,2,5,8,16,19,43,46,54,57,63,135},{609,610,611,614,615,625,678,681,682,685,686,709},{34,35,36,39,40,41,83,92,95,98,101,196},{670,671,672,673,676,677,701,702,705,706,707,719},{135,136,137,140,141,151,207,216,219,232,235,388},{388,389,390,391,394,395,518,519,524,525,531,609},{196,197,198,199,202,203,302,303,318,319,323,447},{447,448,449,452,453,455,565,568,569,574,575,670},{63,64,65,109,110,118,151,164,167,231,234,266},{477,478,479,531,542,543,583,584,592,625,638,641},{81,82,83,118,125,126,174,175,197,267,294,297},{495,496,497,554,555,565,592,599,600,648,649,671},{266,267,268,269,350,351,362,363,422,423,479,495},{227,228,229,237,331,334,341,345,393,412,466,475},{287,288,289,301,357,365,368,375,429,446,494,502},{12,13,14,21,28,33,53,62,70,79,87,159},{633,634,635,643,647,651,684,688,691,696,700,713},{45,46,47,102,104,106,134,137,147,205,211,217},{459,460,461,517,519,521,576,578,580,608,611,621},{99,100,101,128,130,131,195,201,203,308,314,321},{513,514,515,571,573,575,602,604,605,669,675,677},{18,19,20,22,30,36,59,65,76,82,93,165},{639,640,641,645,649,653,686,690,694,698,702,715},{233,234,235,251,333,339,343,351,395,418,472,478},{297,298,299,303,363,367,373,377,431,449,497,508},{159,160,161,169,173,177,237,253,265,277,289,411},{411,412,413,421,425,429,533,537,545,549,557,633},{51,52,53,104,108,112,139,148,160,212,227,241},{465,466,467,523,528,533,578,582,586,613,622,634},{87,88,89,120,124,128,177,187,193,276,288,307},{501,502,503,557,562,567,594,598,602,651,661,667},{211,212,213,221,325,329,331,336,387,400,460,465},{307,308,309,317,370,375,379,381,441,451,503,513},{6,7,8,14,20,27,47,52,58,69,75,146},{620,621,622,624,627,629,680,682,688,690,693,711},{26,27,28,30,38,40,71,77,88,94,99,183},{657,658,659,661,663,669,693,696,698,704,706,717},{217,218,219,223,327,329,333,338,391,401,461,471},{313,314,315,319,372,377,379,383,443,453,509,514},{57,58,59,106,110,114,141,150,166,218,233,247},{471,472,473,525,530,535,580,584,588,615,624,640},{93,94,95,122,126,130,179,189,199,282,298,313},{507,508,509,559,564,569,596,600,604,653,663,673},{165,166,167,171,175,179,251,255,269,283,299,417},{417,418,419,423,427,431,535,543,547,555,559,639},{241,242,243,253,336,341,347,353,403,413,467,483},{275,276,277,291,353,359,365,370,425,437,485,501},{69,70,71,112,117,120,153,169,184,242,259,275},{483,484,485,539,545,551,586,590,594,627,643,658},{146,147,148,150,153,155,221,223,243,249,261,399},{399,400,401,403,405,407,521,528,530,539,541,620},{183,184,185,187,189,195,271,291,293,309,315,435},{435,436,437,439,441,443,551,553,562,564,571,657},{75,76,77,114,117,122,155,171,185,248,260,281},{489,490,491,541,547,553,588,590,596,629,645,659},{247,248,249,255,338,343,349,355,405,419,473,489},{281,282,283,293,355,361,367,372,427,439,491,507},{259,260,261,271,347,349,359,361,407,436,484,490}};
#declare rings=array[12][10] {{22,24,38,40,58,61,79,81,95,97},{4,6,18,25,53,66,94,101,113,115},{8,10,20,28,52,67,91,99,109,111},{26,30,39,42,56,63,77,80,89,93},{50,51,54,55,59,60,64,65,68,69},{16,19,36,37,57,62,82,83,100,103},{1,5,14,27,49,70,92,105,114,118},{0,2,11,34,43,76,85,108,117,119},{7,12,17,32,48,71,87,102,107,112},{23,29,35,44,46,73,75,84,90,96},{15,21,33,41,47,72,78,86,98,104},{3,9,13,31,45,74,88,106,110,116}};

//Modelling Functions
#macro DrawPentagon(face,c)
 #local qlist=array[5] {vertices[face.x],vertices[face.y],vertices[face.z],vertices[face.t],vertices[face.transmit]};
 #local plist=array[5]; #local i=0; #while(i<5) #local plist[i]=StereographicProjection(qlist[i]); #local i=i+1; #end
 union{triangle{plist[0],plist[1],plist[2]} triangle{plist[0],plist[2],plist[3]} triangle{plist[0],plist[3],plist[4]} pigment{rgb c}}
#end
#macro DrawCell(cell,c) #local n=dimension_size(cell,1); #local i=0; #while(i<n) DrawPentagon(faces[cell[i]],c) #local i=i+1; #end #end
#macro DrawRing(ring,c) #local i=0; #while(i<10) DrawCell(nth(ring[i],Cells),c) #local i=i+1; #end #end
#declare colors=array[6] {<1,1,1>,<1,0,0>,<1,1,0>,<0,1,0>,<0,1,1>,<0,0,1>};
#declare i=0; #while(i<6) DrawRing(nth(i,rings),colors[i]) #declare i=i+1; #end
